#----------------------------------------------------------------
# @(#) ericsson/tech_pack_support/v12/EngineConfig.pm ericsson_r3.3.0.3:cset.003067:4:4@(#)
#----------------------------------------------------------------
#
# This perl module contains the configuration information for this parser.
# If you don't understand the format of this configuration file DON'T TOUCH IT.
#
# Ericsson Gateway
# Vendor Version R6.0 - R12.1
#
# Notes
# =====
# The Ericsson Gateway supports the following file formats :
# STFIO, TRAR, TRDIP, MTRVC, C7PM, TRART, MTCES, MTRRCR, SEQS, ASCII
# for version r6.0, r6.1, r7.0, r8.0, r8.1, r9.0  
#
# This EngineConfig.pm is configured for these file types . Each rule entry
# processes the files that match the INPUT_FILE_DESCRIPTION regular 
# expression. It is important that these RE's are configured to exclusively
# present the correct files to each rule, according to its type. This is 
# especially true where the drip feed mechanism is used by configuring 
# NUMBER_OF_FILES_TO_PROCESS
# 

package EngineConfig;

@ISA = qw(Exporter);
@EXPORT = qw(engine_config);

use Exporter ();
use strict;

# VI_CONFIG hashes
my (%C7PM_FIELD_LIST, %MTCES_TACS_FIELD_LIST, %MTCES_AMPS_FIELD_LIST, %MTRRCRFILE_HASH, %MTRVC_FIELD_LIST, %SEQSFILE_HASH);
my (%trafftype,%TRART_FIELD_LIST, %TRART_AMPS_LIST, %STFIOPFILE_HASH);
my (%TRDIPFILE_HASH, %TRAR_FIELD_LIST );

my @rules = (
#####################################################################
#---------------------- C7PMFILE TYPE ------------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_C7PM',
        'RULE_DESC' => 'C7PM Files',
        'INPUT_FILE_DESCRIPTION' => [ '.*C7PM.*$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,

        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)-',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'BLOCKSIZE' => 2048,
        'DATA_BLOCKSIZE'  => 96,
        'SKIP_FIRST_BYTES' => 4,
        'VI_CONFIG' => \%C7PM_FIELD_LIST,
    },

#####################################################################
#---------------------- MTCESFILE TYPE -----------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_MTCES',
        'RULE_DESC' => 'Processing MTCES Format Files',
        'INPUT_FILE_DESCRIPTION' => [ 'MTCES.+$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,

        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)-',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'BLOCKSIZE' => 2048,
        'SKIP_FIRST_BYTES'=> 0,
        'STORE_RECA' => 'True',
        'VI_CONFIG' => \%MTCES_AMPS_FIELD_LIST,
    },

#####################################################################
#---------------------- MTRRCR TYPE --------------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_MTRRCR',
        'RULE_DESC' => 'Processing MTRRCR files',
        'INPUT_FILE_DESCRIPTION' => [ '.*MTRRCR.*$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,
        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)-',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'SKIP_FIRST_BYTES' => 0,
        'BLOCKSIZE' => 2048,
        'VI_CONFIG' => \%MTRRCRFILE_HASH,
    },

#####################################################################
#---------------------- MTRVCFILE TYPE -----------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_MTRVC',
        'RULE_DESC' => 'Processing MTRVC files',
        'INPUT_FILE_DESCRIPTION' => [ '.*MTRVC.*$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,

        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)-',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'BLOCKSIZE' => 2048,
        'DATA_BLOCKSIZE'  => 512,
        'SKIP_FIRST_BYTES' => 0,
        'VI_CONFIG' => \%MTRVC_FIELD_LIST,
    },
  
#####################################################################
#------------------------ SEQS TYPE --------------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_SEQS',
        'RULE_DESC' => 'SEQS files',
        'INPUT_FILE_DESCRIPTION' => [ '.*SEQS.*$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,
        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)-',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'SKIP_FIRST_BYTES' => 0,
        'BLOCKSIZE' => 2048,
        'VI_CONFIG' => \%SEQSFILE_HASH,
    },
 
#####################################################################
#---------------------- TRARTFILE TYPE -----------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_TRART',
        'RULE_DESC' => 'TRART AMPS files',
        'INPUT_FILE_DESCRIPTION' => [ 'TRART.block2048' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,

        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)-',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'ADM_RECORD_SIZE' => 32,
        'BLOCKSIZE' => 2048,
        'DEVDATA_RECORD_SIZE' => 64,
        'DEVDATA_PER_BLOCK' => 4,
        'TRAFFCNT_RECORD_SIZE' => 32,
        'TRAFFCNT_PER_BLOCK' => 56,
        'SKIP_FIRST_BYTES' => 4,
        'VI_CONFIG' => \%TRART_AMPS_LIST,
        'TRAFF_TYPE' => \%trafftype,
    },
   
    {
        'RULE_TYPE' => 'R2P_TRART',
        'RULE_DESC' => 'TRART files',
        'INPUT_FILE_DESCRIPTION' => [ 'TRART.block9\d+' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,

        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)-',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'ADM_RECORD_SIZE' => 32,
        'BLOCKSIZE' => 960,
        'DEVDATA_RECORD_SIZE' => 64,
        'DEVDATA_PER_BLOCK' => 4,
        'TRAFFCNT_RECORD_SIZE' => 64,
        'TRAFFCNT_PER_BLOCK' => 14,
        'SKIP_FIRST_BYTES' => 0,
        'VI_CONFIG' => \%TRART_FIELD_LIST,
        'TRAFF_TYPE' => \%trafftype,
    },

#####################################################################
#---------------------- TRARFILE TYPE ------------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_TRAR',
        'RULE_NAME' => 'Process TRAR Binary files',
        'INPUT_FILE_DESCRIPTION' => [ '.*TRAR.+$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,

        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)#',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'ADM_RECORD_SIZE' => 70,
        'BLOCKSIZE'     => 2048,
        'RECORD_SIZE' => 64,
        'SKIP_FIRST_BYTES' => 0,
        'VI_CONFIG' => \%TRAR_FIELD_LIST,
    },

#####################################################################
#------------------------ TRDIP TYPE -------------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_TRDIP',
        'RULE_DESC' => 'TRDIP files version R6, R7, R8 & R9',
        'INPUT_FILE_DESCRIPTION' => [ '.*TRDIP.*$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,
        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^(\w+)-',
            'FILENAME' => '^(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',

        'SKIP_FIRST_BYTES' => 0,
        'BLOCKSIZE' => 2048,
        'ADM_RECORD_SIZE' => 86,
        'RECORD_SIZE' => 86,
        'VI_CONFIG' => \%TRDIPFILE_HASH,
    },

#####################################################################
#---------------------- STFIOPFILE TYPE ----------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'R2P_STFIOP',
        'RULE_NAME' => 'Convert Ericsson Binary files to PIF files',
        'INPUT_FILE_DESCRIPTION' => [ '^STFIOP.+$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,
        'FILENAME_HEADER_FIELDS' => {
            'NODEID' => '^STFIOP-(\w+)#',
            'FILENAME' => '^STFIOP-(.*)',
        },
        'DIRECTORY_HEADER_FIELDS' => {
            REGION_ID => '\/REGION_?([^\/]+)\/?',
            NETWORK_ID => '\/[^\/]+\/NETWORK_?([^\/]+)\/?',
        },
        'NUMBER_OF_FILES_TO_PROCESS' => 200,
        'ORDER_OF_FILES' => 'DIRECTORY_ORDER',
        'SKIP_FIRST_BYTES' => 0,
        'BLOCKSIZE' => 2048,
        'GEN_REC_SIZE' => 78,
        'VI_CONFIG' => \%STFIOPFILE_HASH,
    },

#####################################################################
#------------------------ ASCII_INTERFACE  -------------------------#
#####################################################################
    {
        'RULE_TYPE' => 'ASCII_INTERFACE',
        'RULE_NAME' => 'Convert Ericsson ASCII Report files to PIF files',
        'INPUT_FILE_DESCRIPTION' => [ 'ASCII.+$' ],
        'INPUT_DIR_DEPTH' => 4,
        'DO_NOT_DELETE'=> 0,

        'JUNK_MATCH'   => [ 'TIME.*PAGE', 'AF-' ],
        'BAD_CHARS'    => [ "\000", "\011", "\015" ],
        'BLANK_MATCH'  => '^[ \t]*$',
        'SUB_SPACES'   => '_',             # used with s/// on counter names
        'REPORT_END'   => '^\s*END',

        'REPORT_TYPES' => [
            {
                TYPE_NAME    => 'STS',
                LEADING_TEXT => '^\s*STATISTIC DATA REPORT',
                LAYOUT       => 'multi-object',
                REPORT_START => '\s*REPORT DATA',
                OBJECT_START => '^\s*OBJTYPE',
                FAILURE_HDR  => [ 'CFAIL' ],
                FAILURE_OBJ  => [ '\s*FAULT CODE' ],
                FAILURE_TXT  => [ '\s*FAULT INTERRUPT' ],
                USE_NAMES    => 0,
                TIME_TO_USE  => 'STIME',
                EXTRACT_NODE => [ '(\w+).*', '$1' ]
            },
            {
                TYPE_NAME    => 'CCITT7_1',
                LEADING_TEXT => '^\s*CCITT7',
                KEY_MATCH    => [ 'DEST', 'SPID' ],
                LAYOUT       => 'tabular',
                FAILURE_HDR  => [ 'FCODE' ]
            },
            {
                TYPE_NAME    => 'CCITT7_2',
                LEADING_TEXT => '^\s*CCITT7',
                KEY_MATCH    => [ 'LS', 'SPID' ],
                LAYOUT       => '2-level',
                FAILURE_HDR  => [ 'FCODE' ]
            },
            {
                TYPE_NAME    => 'TRARMET',
                LEADING_TEXT => '\s*TRAFFIC MEASUREMENT',
                LAYOUT       => 'tabular',
                FAILURE_HDR  => [ 'FCODE' ]
            },
            {
                TYPE_NAME    => 'TRARTMET',
                LEADING_TEXT => '\s*TRAFFIC TYPE MEASUREMENT',
                LAYOUT       => 'tabular',
                FILLIN       => 'TRAFFTYPE',
                FAILURE_HDR  => [ 'FCODE' ]
            },
            {
                TYPE_NAME    => 'TRDIPMET',
                LEADING_TEXT => '\s*TRAFFIC DISPERSION',
                LAYOUT       => 'tabular',
                PROPAGATE    => [ 'R', 'TRDG' ],
                FAILURE_HDR  => [ 'FCODE' ]
            }
        ]
    },
);

# ***************************************************************** #
######################
# VI_CONFIG hashes   #
######################

#####################################################################
#---------------------- TRAR TYPE ----------------------------------#
#####################################################################

%TRAR_FIELD_LIST = (
#---- ADM RECORD --------------------------------------------------- 
  ADM=>[
    {NAME => 'RECORD_TYPE',                POS =>  0, SIZE => 1, },
    {NAME => 'EXCH_ID',                    POS =>  1, SIZE => 12,}, 
    {NAME => 'MEASURING_PROG',             POS => 13, SIZE => 3, },
    {NAME => 'SEQ_NO_RES_OPERIOD',         POS => 16, SIZE => 3, },
    {NAME => 'GLOBAL_NO_RES_OPERIOD',      POS => 19, SIZE => 5, },
    {NAME => 'NO_RES_OPERIOD',             POS => 24, SIZE => 3, },
    {NAME => 'REC_GROUP_NO',               POS => 27, SIZE => 3, },
    {NAME => 'START_DATE',                 POS => 30, SIZE => 6, },
    {NAME => 'START_TIME',                 POS => 36, SIZE => 4, },
    {NAME => 'LENGTH_OF_RESULT',           POS => 40, SIZE => 4, },
    {NAME => 'SCANNING_PERIOD',            POS => 44, SIZE => 2, },
    {NAME => 'DAY_TIME_FOR_OUTPUT',        POS => 46, SIZE => 6, },
    {NAME => 'NO_RECORDS',                 POS => 52, SIZE => 2, },
    {NAME => 'NO_ACCUMULATIONS_TRAFFL',    POS => 54, SIZE => 5, },
    {NAME => 'NO_ACCUMULATIONS_BLOCKL',    POS => 59, SIZE => 3, },
    {NAME => 'ID_GROUP_COMPLETE',          POS => 62, SIZE => 1, },
    {NAME => 'ID_MEASURING_PROGRAM',       POS => 63, SIZE => 1, },
    {NAME => 'FAULT_CODE',                 POS => 64, SIZE => 2, },
    {NAME => 'NETWORK_MGMT_RESULT',        POS => 66, SIZE => 2, },
    {NAME => 'FILLER',                     POS => 68, SIZE => 2, },
  ],

#---- ROUTELOSS RECORD --------------------------------------------- 
  1=>[
    {NAME => 'ROUTE_NAME',                 POS =>  0, SIZE => 7, },
    {NAME => 'NO_DEVICES',                 POS =>  7, SIZE => 5, },
    {NAME => 'NO_BIDS',                    POS => 12, SIZE => 7, },
    {NAME => 'NO_UBIDS',                   POS => 19, SIZE => 5, },
    {NAME => 'SUM_BDEVS',                  POS => 24, SIZE => 5, },
    {NAME => 'SUM_TRAFFL',                 POS => 29, SIZE => 7, },
    {NAME => 'NO_BANSWERS',                POS => 36, SIZE => 7, },
    {NAME => 'FILLER',                     POS => 43, SIZE => 21,},
  ],

#---- ROUTEQUEUE RECORD --------------------------------------------
  2=>[
    {NAME => 'ROUTE_NAME',                 POS =>  0, SIZE => 7, },
    {NAME => 'O_DEVICES',                  POS =>  7, SIZE => 4, },
    {NAME => 'NO_BIDS',                    POS => 11, SIZE => 7, },
    {NAME => 'NO_BIDS_TO_QUEUE',           POS => 18, SIZE => 5, },
    {NAME => 'SUM_OF_BLOCKED_DEVICES',     POS => 23, SIZE => 5, },
    {NAME => 'SUM_OF_TRAFFL',              POS => 28, SIZE => 7, },
    {NAME => 'NO_BIDS_AFTER_QUEUE',        POS => 35, SIZE => 4, },
    {NAME => 'SUM_OF_QUEUE_LEVEL',         POS => 39, SIZE => 5, },
    {NAME => 'FILLER',                     POS => 44, SIZE => 20,},
  ],
#---- ROUTEPBX RECORD ----------------------------------------------
  3=>[
    {NAME => 'ROUTE_NAME',                 POS =>  0, SIZE => 7, },
    {NAME => 'GROUP_NUMBER',               POS =>  7, SIZE => 10,},
    {NAME => 'NO_LINES',                   POS => 17, SIZE => 4, },
    {NAME => 'NO_BIDS',                    POS => 21, SIZE => 7, },
    {NAME => 'NO_UBIDS',                   POS => 28, SIZE => 5, },
    {NAME => 'SUM_BLOCKL',                 POS => 33, SIZE => 5, },
    {NAME => 'SUM_TRAFFL_IN',              POS => 38, SIZE => 7, },
    {NAME => 'SUM_TRAFFL_OUT',             POS => 45, SIZE => 7, },
    {NAME => 'FILLER',                     POS => 52, SIZE => 12,},
  ],

#---- ADM1 RECORD --------------------------------------------------
  4=>[
    {NAME => 'RECORD_TYPE',                POS =>  0, SIZE => 1, },
    {NAME => 'EXCH_ID',                    POS =>  1, SIZE => 12,}, 
    {NAME => 'MEASURING_PROG',             POS => 13, SIZE => 3, },
    {NAME => 'START_DATE',                 POS => 16, SIZE => 6, },
    {NAME => 'START_TIME',                 POS => 22, SIZE => 4, },
    {NAME => 'REASON_FOR_RECOVERY',        POS => 26, SIZE => 1, },
    {NAME => 'FIRST_LOST_OPERIOD_NO',      POS => 27, SIZE => 5, },
    {NAME => 'LAST_LOST_OPERIOD_NO',       POS => 32, SIZE => 5, },
    {NAME => 'FILLER',                     POS => 37, SIZE => 30,},
  ],
);

#####################################################################
#---------------------- TRART TYPE ---------------------------------#
#####################################################################

%TRART_FIELD_LIST = (

#---- ADM1 RECORD -------------------------------------------------- 
  ADM1=>[
    {NAME => 'RECORDING_TYPE',             POS =>  0, SIZE => 1, },  
    {NAME => 'BLOCK_COUNTER',              POS =>  1, SIZE => 1, },  
    {NAME => 'LAST_BLOCK_IND',             POS =>  2, SIZE => 1, },  
    {NAME => 'EXCH_ID',                    POS =>  3, SIZE => 12,},  
    {NAME => 'MEASURING_PROG',             POS => 15, SIZE => 3, },  
    {NAME => 'FILLER',                     POS => 18, SIZE => 14,},  
  ],
  
#---- ADM2 RECORD -------------------------------------------------- 
  ADM2=>[
    {NAME => 'START_DATE',                 POS =>  0, SIZE => 6, },  
    {NAME => 'START_TIME',                 POS =>  6, SIZE => 4, },  
    {NAME => 'SCANCNTTRAFF',               POS => 10, SIZE => 4, },  
    {NAME => 'SCANCNTBLO',                 POS => 14, SIZE => 3, },  
    {NAME => 'RPN',                        POS => 17, SIZE => 3, },  
    {NAME => 'GRN',                        POS => 20, SIZE => 5, },  
    {NAME => 'RPL',                        POS => 25, SIZE => 4, },  
    {NAME => 'NRP',                        POS => 29, SIZE => 3, },  
    {NAME => 'NM',                         POS => 32, SIZE => 1, },  
    {NAME => 'FILLER',                     POS => 33, SIZE => 31,},  
  ],
  
#---- DEVDATA RECORD ----------------------------------------------- 
  DEVDATA=>[
    {NAME => 'DEVDATA_TYPE',               POS =>  0, SIZE => 1, },  
    {NAME => 'NDEVO',                      POS =>  1, SIZE => 5, },  
    {NAME => 'NDEVB',                      POS =>  6, SIZE => 5, },  
    {NAME => 'NBLOO',                      POS => 11, SIZE => 5, },  
    {NAME => 'NBLOB',                      POS => 16, SIZE => 5, },  
    {NAME => 'FILLER',                     POS => 21, SIZE => 43,},  
  ],
  
#---- TRAFFCNT RECORD ---------------------------------------------- 
  TRAFFCNT=>[
    {NAME => 'ORIGIN_CODE',                POS =>  0, SIZE => 2, },  
    {NAME => 'DESTINATION_CODE',           POS =>  2, SIZE => 2, },  
    {NAME => 'TRAFF_LEVEL_NO',             POS =>  4, SIZE => 7, },  
    {NAME => 'NO_CALLS',                   POS => 11, SIZE => 7, },  
    {NAME => 'NO_CALLS_INT_CGTN',          POS => 18, SIZE => 7, },  
    {NAME => 'NO_CALLS_EXT_CGTN',          POS => 25, SIZE => 7, },  
    {NAME => 'NO_UNS_CALLS',               POS => 32, SIZE => 7, },  
    {NAME => 'NO_SUCC_CALLS',              POS => 39, SIZE => 7, },  
    {NAME => 'NO_BANSWERS',                POS => 46, SIZE => 7, },  
    {NAME => 'FILLER',                     POS => 53, SIZE => 11,},  
  ],
  
#---- RECOVERY RECORD ---------------------------------------------- 
  RECOVERY=>[
    {NAME => 'RESTART_TIME',               POS =>  0, SIZE => 10,},
    {NAME => 'REASON_FOR_RECOVERY',        POS => 10, SIZE => 1, },
    {NAME => 'FIRST_LOST_OPERIOD_NO',      POS => 11, SIZE => 5, },
    {NAME => 'LAST_LOST_OPERIOD_NO',       POS => 16, SIZE => 5, },
    {NAME => 'FILLER',                     POS => 21, SIZE => 43,},  
  ],
);

%TRART_AMPS_LIST = (

#---- ADM1 RECORD -------------------------------------------------- 
  ADM1=>[
    {NAME => 'RECORDING_TYPE',             POS =>  0, SIZE => 1, },  
    {NAME => 'BLOCK_COUNTER',              POS =>  1, SIZE => 1, },  
    {NAME => 'LAST_BLOCK_IND',             POS =>  2, SIZE => 1, },  
    {NAME => 'EXCH_ID',                    POS =>  3, SIZE => 12,},  
    {NAME => 'MEASURING_PROG',             POS => 15, SIZE => 3, },  
    {NAME => 'START_DATE_1',               POS => 18, SIZE => 6, },  
    {NAME => 'START_TIME_1',               POS => 24, SIZE => 4, }, 
  ],
  
#---- ADM2 RECORD -------------------------------------------------- 
  ADM2=>[
    {NAME => 'START_DATE',                 POS =>  0, SIZE => 6, },  
    {NAME => 'START_TIME',                 POS =>  6, SIZE => 4, },  
    {NAME => 'SCANCNTTRAFF',               POS => 10, SIZE => 4, },  
    {NAME => 'SCANCNTBLO',                 POS => 14, SIZE => 3, },  
    {NAME => 'RPN',                        POS => 17, SIZE => 3, },  
    {NAME => 'GRN',                        POS => 20, SIZE => 5, },  
    {NAME => 'RPL',                        POS => 25, SIZE => 4, },  
    {NAME => 'NRP',                        POS => 29, SIZE => 3, },  
    {NAME => 'NM',                         POS => 32, SIZE => 1, },  
    {NAME => 'FILLER',                     POS => 33, SIZE => 31,},  
  ],
  
#---- DEVDATA RECORD ----------------------------------------------- 
  DEVDATA=>[
    {NAME => 'DEVDATA_TYPE',               POS =>  0, SIZE => 1, },  
    {NAME => 'NDEVO',                      POS =>  1, SIZE => 5, },  
    {NAME => 'NDEVB',                      POS =>  6, SIZE => 5, },  
    {NAME => 'NBLOO',                      POS => 11, SIZE => 5, },  
    {NAME => 'NBLOB',                      POS => 16, SIZE => 5, },  
    {NAME => 'FILLER',                     POS => 21, SIZE => 43,},  
  ],
  
#---- TRAFFCNT RECORD ---------------------------------------------- 
  TRAFFCNT=>[
    {NAME => 'ORIGIN_CODE',                POS =>  0, SIZE => 2, },  
    {NAME => 'DESTINATION_CODE',           POS =>  2, SIZE => 2, },  
    {NAME => 'TRAFF_LEVEL_NO',             POS =>  4, SIZE => 7, },  
    {NAME => 'BID_COUNTER',                POS => 11, SIZE => 7, },  
    {NAME => 'UNSUCCESSFUL_BID',           POS => 18, SIZE => 5, },   
    {NAME => 'FILLER',                     POS => 23, SIZE => 9,},  
  ],
  
#---- RECOVERY RECORD ---------------------------------------------- 
  RECOVERY=>[
    {NAME => 'RESTART_TIME',               POS =>  0, SIZE => 10,},
    {NAME => 'REASON_FOR_RECOVERY',        POS => 10, SIZE => 1, },
    {NAME => 'FIRST_LOST_OPERIOD_NO',      POS => 11, SIZE => 5, },
    {NAME => 'LAST_LOST_OPERIOD_NO',       POS => 16, SIZE => 5, },
    {NAME => 'FILLER',                     POS => 21, SIZE => 43,},  
  ],
);

#---- HASH used to determine TRAFFTYPE for DEVDATA -----------------
%trafftype = ( 
# DEVDATA TYPES: -------------------------------------------------
  '1' => 'ORG', '2' => 'IEX', '3' => 'TE', '4' => 'OEX',
);

#####################################################################
#---------------------- MTCES TYPE ---------------------------------#
#####################################################################

%MTCES_TACS_FIELD_LIST = (

#---- SUBRECORD TYPE 33 ADMIN  - RECORD A -------------------------- 
  33=>[
    {NAME => 'FUNCTION_CODE',             POS =>  0, SIZE => 2, BC=> 'C'},  
    {NAME => 'SUBRECORD_TYPE',            POS =>  2, SIZE => 1, BC=> 'C'},  
    {NAME => 'EXCH_DESIGNATION',          POS =>  3, SIZE => 23,},  
    {NAME => 'MEASURING_PROG',            POS => 26, SIZE => 1, BC=> 'C'},  
    {NAME => 'NO_RESULTS_OPERIOD',        POS => 27, SIZE => 2, BC=> 'C'},  
    {NAME => 'SEPARATION_CHAR',           POS => 29, SIZE => 1, BC=> 'C'},  

    {NAME => 'START_YEAR',                POS => 30, SIZE => 1, BC=>'C'},  
    {NAME => 'START_MONTH',               POS => 31, SIZE => 1, BC=>'C'},  
    {NAME => 'START_DAY',                 POS => 32, SIZE => 1, BC=>'C'},  

    {NAME => 'SELECTION_CRITERIA',        POS => 33, SIZE => 1, BC=> 'C'},  
    {NAME => 'INDICATOR_FOR_END_A',       POS => 34, SIZE => 1, BC=> 'C'},  
    {NAME => 'NO_SUBRECORDS',             POS => 35, SIZE => 1, BC=> 'C'},  
    {NAME => 'INDICATOR_FOR_END_SUB',     POS => 36, SIZE => 1, BC=> 'C'},  
  ],

#---- SUBRECORD TYPE 34 ADMIN  - RECORD A -------------------------- 
  34=>[
    {NAME => 'SUBRECORD_TYPE',            POS =>  0, SIZE => 1, BC=> 'C'},  
    {NAME => 'COUNTER_GRP',               POS =>  1, SIZE => 1, BC=> 'C'},  
    {NAME => 'TRAFF_EVT_STRING',          POS =>  2, SIZE => 7, },  
    {NAME => 'INDICATOR_FOR_END_SUB',     POS =>  9, SIZE => 1, BC=> 'C'},  
  ],

#---- TACS SUBRECORD TYPE 32 ADMIN  - RECORD B -------------------------- 
  32=>[
    {NAME => 'FUNCTION_CODE',             POS =>  0, SIZE => 2, BC=> 'C'},
    {NAME => 'SUBRECORD_TYPE',            POS =>  2, SIZE => 1, BC=> 'C'},
    {NAME => 'EXCH_DESIGNATION',          POS =>  3, SIZE => 23,},
    {NAME => 'MEASURING_PROG',            POS => 26, SIZE => 1, BC=> 'C'},
    {NAME => 'NO_RESULTS_OPERIOD',        POS => 27, SIZE => 2, BC=> 'C'},
    {NAME => 'LGTH_RESULTS_OPERIOD',      POS => 29, SIZE => 2, BC=> 'C'},
    {NAME => 'TRAFF_RECORD_GRP',          POS => 31, SIZE => 1, BC=> 'C'},
    {NAME => 'NO_SUBRECORDS',             POS => 32, SIZE => 2, BC=> 'C'},
    {NAME => 'INDICATOR_FOR_END_B',       POS => 34, SIZE => 1, BC=> 'C'},
    {NAME => 'START_HOUR',                POS => 35, SIZE => 1, BC=> 'C'},
    {NAME => 'START_MINUTE',              POS => 36, SIZE => 1, BC=> 'C'},
    {NAME => 'OUTPUT_CODE',               POS => 37, SIZE => 1, BC=> 'C'},
    {NAME => 'CELL_NAME',                 POS => 38, SIZE => 7, },
    {NAME => 'INDICATOR_FOR_END_SUB',     POS => 45, SIZE => 1, BC=> 'C'},
  ], 

#---- SUBRECORD TYPE 0-31 RESULT SUBRECORD - RECORD B -------------- 
  RECORD=>[
    {NAME => 'SUBRECORD_TYPE',            POS =>  0, SIZE => 1, BC=> 'C'},
    {NAME => 'NO_ACCUMULATIONS',          POS =>  1, SIZE => 2, BC=> 'C'},
    {NAME => 'ACCUMULATOR',               POS =>  3, SIZE => 2, BC=> 'C'},
    {NAME => 'INDICATOR_FOR_END_SUB',     POS =>  5, SIZE => 1, BC=> 'C'},
  ],
);

%MTCES_AMPS_FIELD_LIST = (

#---- SUBRECORD TYPE 33 ADMIN  - RECORD A -------------------------- 
  33=>[
    {NAME => 'FUNCTION_CODE',             POS =>  0, SIZE => 2, BC=> 'C'},  
    {NAME => 'SUBRECORD_TYPE',            POS =>  2, SIZE => 1, BC=> 'C'},  
    {NAME => 'EXCH_DESIGNATION',          POS =>  3, SIZE => 23,},  
    {NAME => 'MEASURING_PROG',            POS => 26, SIZE => 1, BC=> 'C'},  
    {NAME => 'NO_RESULTS_OPERIOD',        POS => 27, SIZE => 2, BC=> 'C'},  
    {NAME => 'SEPARATION_CHAR',           POS => 29, SIZE => 1, BC=> 'C'},  

    {NAME => 'START_YEAR',                POS => 30, SIZE => 1, BC=>'C'},  
    {NAME => 'START_MONTH',               POS => 31, SIZE => 1, BC=>'C'},  
    {NAME => 'START_DAY',                 POS => 32, SIZE => 1, BC=>'C'},  

    {NAME => 'SELECTION_CRITERIA',        POS => 33, SIZE => 1, BC=> 'C'},  
    {NAME => 'INDICATOR_FOR_END_A',       POS => 34, SIZE => 1, BC=> 'C'},  
    {NAME => 'NO_SUBRECORDS',             POS => 35, SIZE => 1, BC=> 'C'},  
    {NAME => 'INDICATOR_FOR_END_SUB',     POS => 36, SIZE => 1, BC=> 'C'},  
  ],

#---- SUBRECORD TYPE 34 ADMIN  - RECORD A -------------------------- 
  34=>[
    {NAME => 'SUBRECORD_TYPE',            POS =>  0, SIZE => 1, BC=> 'C'},  
    {NAME => 'COUNTER_GRP',               POS =>  1, SIZE => 1, BC=> 'C'},  
    {NAME => 'TRAFF_EVT_STRING',          POS =>  2, SIZE => 7, },  
    {NAME => 'INDICATOR_FOR_END_SUB',     POS =>  9, SIZE => 1, BC=> 'C'},  
  ],

#---- AMPS SUBRECORD TYPE 32 ADMIN  - RECORD B -------------------------- 
  32=>[
    {NAME => 'FUNCTION_CODE',             POS =>  0, SIZE => 2, BC=> 'C'},  
    {NAME => 'SUBRECORD_TYPE',            POS =>  2, SIZE => 1, BC=> 'C'},  
    {NAME => 'EXCH_DESIGNATION',          POS =>  3, SIZE => 23,},  
    {NAME => 'MEASURING_PROG',            POS => 26, SIZE => 1, BC=> 'C'},  
    {NAME => 'NO_RESULTS_OPERIOD',        POS => 27, SIZE => 2, BC=> 'C'},  
    {NAME => 'LGTH_RESULTS_OPERIOD',      POS => 29, SIZE => 2, BC=> 'C'},  
    {NAME => 'TRAFF_RECORD_GRP',          POS => 31, SIZE => 1, BC=> 'C'},  
    {NAME => 'NO_SUBRECORDS',             POS => 32, SIZE => 2, BC=> 'C'},  
    {NAME => 'INDICATOR_FOR_END_B',       POS => 34, SIZE => 1, BC=> 'C'},

    {NAME => 'START_YEAR',                POS => 35, SIZE => 1, BC=>'C'},  
    {NAME => 'START_MONTH',               POS => 36, SIZE => 1, BC=>'C'},  
    {NAME => 'START_DAY',                 POS => 37, SIZE => 1, BC=>'C'},  
    {NAME => 'START_HOUR',                POS => 38, SIZE => 1, BC=> 'C'},  
    {NAME => 'START_MINUTE',              POS => 39, SIZE => 1, BC=> 'C'},  

    {NAME => 'OUTPUT_CODE',               POS => 40, SIZE => 1, BC=> 'C'},  
    {NAME => 'CELL_NAME',                 POS => 41, SIZE => 7, },  
    {NAME => 'INDICATOR_FOR_END_SUB',     POS => 48, SIZE => 1, BC=> 'C'},
  ], 

#---- SUBRECORD TYPE 0-31 RESULT SUBRECORD - RECORD B -------------- 
  RECORD=>[
    {NAME => 'SUBRECORD_TYPE',            POS =>  0, SIZE => 1, BC=> 'C'},  
    {NAME => 'NO_ACCUMULATIONS',          POS =>  1, SIZE => 2, BC=> 'C' },  
    {NAME => 'ACCUMULATOR',               POS =>  3, SIZE => 2, BC=> 'C'},  
    {NAME => 'INDICATOR_FOR_END_SUB',     POS =>  5, SIZE => 1, BC=> 'C'},  
  ],
);


#####################################################################
#---------------------- C7PM TYPE ----------------------------------#
#####################################################################

%C7PM_FIELD_LIST = (

#---- MPHEAD ----------------------------------------------------- 
  MPHEAD=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 2, BC=>'C'},  
    {NAME => 'MEASURING_PROG',            POS =>  2, SIZE => 2, BC=>'C'},  
    {NAME => 'TRG',                       POS =>  4, SIZE => 2, BC=>'C'},  
    {NAME => 'NRP',                       POS =>  6, SIZE => 2, BC=>'C'},  
    {NAME => 'RPL',                       POS =>  8, SIZE => 2, BC=>'C'},  
    {NAME => 'RPN',                       POS => 10, SIZE => 2, BC=>'C'},  
    {NAME => 'GRN',                       POS => 12, SIZE => 2, BC=>'C'},  

    {NAME => 'START_YEAR',                POS => 14, SIZE => 2, BC=>'v'},  
    {NAME => 'START_DAY',                 POS => 16, SIZE => 1, BC=>'C'},  
    {NAME => 'START_MONTH',               POS => 17, SIZE => 1, BC=>'C'},  

    {NAME => 'START_MINUTE',              POS => 18, SIZE => 1, BC=>'C'},  
    {NAME => 'START_HOUR',                POS => 19, SIZE => 1, BC=>'C'},  

    {NAME => 'FAULT_CODE',                POS => 20, SIZE => 2, BC=>'C'},  
    {NAME => 'TRGTYPE',                   POS => 22, SIZE => 2, BC=>'C'},  
    {NAME => 'OBJECTCNT',                 POS => 24, SIZE => 2, BC=>'C'},  
    {NAME => 'FILLER',                    POS => 26, SIZE => 70,},  
  ],

#---- LSCOUNT ----------------------------------------------------- 
  LSCOUNT=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 2, BC=>'C'},  
    {NAME => 'LS_NI',                     POS =>  2, SIZE => 2, BC=>'C'},  
    {NAME => 'LS_SPC',                    POS =>  4, SIZE => 2, BC=>'C'},  
    {NAME => 'SPID',                      POS =>  6, SIZE => 8, },  
    {NAME => 'NOSL',                      POS => 14, SIZE => 2, BC=>'C'},  
    {NAME => 'NLSFA',                     POS => 16, SIZE => 2, BC=>'C'},  
    {NAME => 'DLSUNAV',                   POS => 18, SIZE => 4, BC=>'I'},  
    {NAME => 'FILLER',                    POS => 22, SIZE => 74,},  
  ],

#---- SLCOUNT ----------------------------------------------------- 
  SLCOUNT=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 2, BC=>'C'},  
    {NAME => 'SL',                        POS =>  2, SIZE => 2, BC=>'C'},  
    {NAME => 'NFTOT',                     POS =>  4, SIZE => 2, BC=>'C'},  
    {NAME => 'NFABN',                     POS =>  6, SIZE => 2, BC=>'C'},  
    {NAME => 'NFACK',                     POS =>  8, SIZE => 2, BC=>'C'},  
    {NAME => 'NFEER',                     POS => 10, SIZE => 2, BC=>'C'},  
    {NAME => 'NFECO',                     POS => 12, SIZE => 2, BC=>'C'},  
    {NAME => 'NFALN',                     POS => 14, SIZE => 2, BC=>'C'},  
    {NAME => 'NACKNER',                   POS => 16, SIZE => 2, BC=>'C'},  
    {NAME => 'NMSUE',                     POS => 18, SIZE => 2, BC=>'C'},  
    {NAME => 'NLOSS',                     POS => 20, SIZE => 2, BC=>'C'},  
    {NAME => 'NAUCO',                     POS => 22, SIZE => 2, BC=>'C'},  
    {NAME => 'NAUCB',                     POS => 24, SIZE => 2, BC=>'C'},  
    {NAME => 'NMACB',                     POS => 26, SIZE => 2, BC=>'C'},  
    {NAME => 'NLOCO',                     POS => 28, SIZE => 2, BC=>'C'},  
    {NAME => 'NRECO',                     POS => 30, SIZE => 2, BC=>'C'},  
    {NAME => 'NRBLO',                     POS => 32, SIZE => 2, BC=>'C'},  
    {NAME => 'NMSUDIS',                   POS => 34, SIZE => 4, BC=>'I'},  
    {NAME => 'NSLCO',                     POS => 38, SIZE => 2, BC=>'C'},  
    {NAME => 'NOCTTR',                    POS => 40, SIZE => 4, BC=>'I'},  
    {NAME => 'NOCTRE',                    POS => 44, SIZE => 4, BC=>'I'},  
    {NAME => 'NOCTRTR',                   POS => 48, SIZE => 4, BC=>'I'},  
    {NAME => 'NMSUTR',                    POS => 52, SIZE => 4, BC=>'I'},  
    {NAME => 'NMSURE',                    POS => 56, SIZE => 4, BC=>'I'},  
    {NAME => 'DUNAVTOT',                  POS => 60, SIZE => 4, BC=>'n'},  
    {NAME => 'DUNAVIS',                   POS => 64, SIZE => 4, BC=>'n'},  
    {NAME => 'DUNAVLOM',                  POS => 68, SIZE => 4, BC=>'n'},  
    {NAME => 'DUNAVREM',                  POS => 72, SIZE => 4, BC=>'n'},  
    {NAME => 'DUNAVSLF',                  POS => 74, SIZE => 4, BC=>'n'},  
    {NAME => 'DUNAVLBL',                  POS => 80, SIZE => 4, BC=>'n'},  
    {NAME => 'DUNAVRBL',                  POS => 84, SIZE => 4, BC=>'n'},  
    {NAME => 'DUNAVCO',                   POS => 88, SIZE => 4, BC=>'n'},  
    {NAME => 'FILLER',                    POS => 92, SIZE => 4, },  
  ],

#---- DESTCOUNT --------------------------------------------------- 
  DESTCOUNT=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 2, BC=>'C'},  
    {NAME => 'DEST',                      POS =>  2, SIZE => 4, BC=>'C'},  
    {NAME => 'SPID',                      POS =>  6, SIZE => 8, },  
    {NAME => 'NDSTU',                     POS => 14, SIZE => 2, BC=>'C'},  
    {NAME => 'NDSTTR',                    POS => 16, SIZE => 4, BC=>'C'},  
    {NAME => 'DDSTU',                     POS => 20, SIZE => 4, BC=>'C'},  
    {NAME => 'FILLER',                    POS => 24, SIZE => 72,},  
  ],
);

#####################################################################
#---------------------- MTRVC TYPE ---------------------------------#
#####################################################################

%MTRVC_FIELD_LIST = (

#---- RECORD TYPE A, ADMIN, ISO ----------------------------------- 
  REC_A=>[
    {NAME => 'FUNCTION_CODE',             POS =>  0, SIZE => 2, },  
    {NAME => 'REVISION',                  POS =>  2, SIZE => 1, },  
    {NAME => 'DELIMITER',                 POS =>  3, SIZE => 1, BC=>'C' },  
    {NAME => 'EXCH_DESIGNATION',          POS =>  4, SIZE => 31,},  
    {NAME => 'MEASURING_PROG',            POS => 35, SIZE => 3, },  
    {NAME => 'RESULT_OPERIOD',            POS => 38, SIZE => 3, },  
    {NAME => 'NO_OPERIODS',               POS => 41, SIZE => 3, },  
    {NAME => 'LGTH_OPERIODS',             POS => 44, SIZE => 4, },  
    {NAME => 'START_DATE',                POS => 48, SIZE => 6, },  
    {NAME => 'START_TIME',                POS => 52, SIZE => 4, },  
    {NAME => 'OUTPUT_CODE',               POS => 58, SIZE => 1, },  
    {NAME => 'RESTART_INDICATOR',         POS => 59, SIZE => 1, },  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 60, SIZE => 1, BC=>'C' },  

## For TACS system, use this configuration:
    # {NAME => 'OUTPUT_CODE',               POS => 58, SIZE => 2, },  
    # {NAME => 'RESTART_INDICATOR',         POS => 60, SIZE => 1, },  
    # {NAME => 'INDICATOR_FOR_END_R',       POS => 61, SIZE => 1, BC=>'C' },  
  ],

#---- RECORD TYPE B, ADMIN, ISO ----------------------------------- 
  REC_B=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 1, },  
    {NAME => 'CELL_EXCH_RESULT',          POS =>  1, SIZE => 1, },
    {NAME => 'NO_RECORDS',                POS =>  2, SIZE => 3, },  
    {NAME => 'CELL_NAME',                 POS =>  5, SIZE => 7, },  
    {NAME => 'MOBILETRAFF_REC_GRP',       POS => 12, SIZE => 16,},  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 28, SIZE => 1, BC=>'C' },  
  ],

#---- RECORD TYPE C1, VCG, ISO ------------------------------------ 
  C1=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 1, },  
    {NAME => 'VOICE_CH_GRP',              POS =>  1, SIZE => 7, },
    {NAME => 'AVG_BDEVS',                 POS =>  8, SIZE => 5, REAL_ISO=> 1},  
    {NAME => 'AVG_SLD_DEVS',              POS => 13, SIZE => 5, REAL_ISO=> 1},  
    {NAME => 'AVG_SZD_DEVS',              POS => 18, SIZE => 5, REAL_ISO=> 1},  
    {NAME => 'NO_DEVS',                   POS => 23, SIZE => 5, },  
    {NAME => 'NO_V_CHSZ',                 POS => 28, SIZE => 10,},  
    {NAME => 'NO_SUCC',                   POS => 38, SIZE => 10,},  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 48, SIZE => 1, },  
  ],

#---- RECORD TYPE C2, VCG, ISO/BINARY ------------------------------ 
  C2=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 1, BC=>'C' },  
    {NAME => 'VOICE_CH_GRP',              POS =>  1, SIZE => 7, },
    {NAME => 'AVG_BDEVS',                 POS =>  8, SIZE => 2, BC=>'n', REAL_BIN=> 1}, 
 
    {NAME => 'AVG_SLD_DEVS',              POS => 10, SIZE => 2, BC=>'n', REAL_BIN=> 1}, 
 
    {NAME => 'AVG_SZD_DEVS',              POS => 12, SIZE => 2, BC=>'n', REAL_BIN=> 1}, 
 
    {NAME => 'NO_DEVS',                   POS => 14, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_V_CHSZ_1',               POS => 16, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_V_CHSZ_2',               POS => 18, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_SUCC_1',                 POS => 20, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_SUCC_2',                 POS => 22, SIZE => 2, BC=>'n' },  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 24, SIZE => 1, BC=>'C' },  
  ],

#---- RECORD TYPE D1, CTYPE, ISO ----------------------------------- 
  D1=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 1, },  
    {NAME => 'CALL_TYPE',                 POS =>  1, SIZE => 7, },
    {NAME => 'NO_V_CHSZ_1',               POS =>  8, SIZE => 5, },  
    {NAME => 'NO_V_CHSZ_2',               POS => 13, SIZE => 5, },  
    {NAME => 'NO_SUCC_1',                 POS => 18, SIZE => 5, },  
    {NAME => 'NO_SUCC_2',                 POS => 23, SIZE => 5, },  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 28, SIZE => 1, BC=>'C' },  
  ],

#---- RECORD TYPE D2, CTYPE, ISO/BINARY ---------------------------- 
  D2=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 1, BC=>'C' },  
    {NAME => 'CALL_TYPE',                 POS =>  1, SIZE => 7, },
    {NAME => 'NO_V_CHSZ_1',               POS =>  8, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_V_CHSZ_2',               POS => 10, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_SUCC_1',                 POS => 12, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_SUCC_2',                 POS => 14, SIZE => 2, BC=>'n' },  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 16, SIZE => 1, BC=>'C' },  
  ],

#---- RECORD TYPE E1, CMODE, ISO ------------------------------------ 
  E1=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 1, },  
    {NAME => 'CALL_MODE',                 POS =>  1, SIZE => 1, },
    {NAME => 'AVG_SZD_DEVS',              POS =>  2, SIZE => 5, },  
    {NAME => 'NO_V_CHSZ_1',               POS =>  7, SIZE => 5, },  
    {NAME => 'NO_V_CHSZ_2',               POS => 12, SIZE => 5, },  
    {NAME => 'NO_SUCC_1',                 POS => 17, SIZE => 5, },  
    {NAME => 'NO_SUCC_2',                 POS => 22, SIZE => 5, },  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 27, SIZE => 1, BC=>'C' },  
  ],

#---- RECORD TYPE E2, CMODE, ISO/BINARY ----------------------------- 
  E2=>[
    {NAME => 'RECORD_TYPE',               POS =>  0, SIZE => 1, BC=>'C' },  
    {NAME => 'CALL_MODE',                 POS =>  1, SIZE => 1, BC=>'C' },
    {NAME => 'AVG_SZD_DEVS',              POS =>  2, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_V_CHSZ_1',               POS =>  4, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_V_CHSZ_2',               POS =>  6, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_SUCC_1',                 POS =>  8, SIZE => 2, BC=>'n' },  
    {NAME => 'NO_SUCC_2',                 POS =>  0, SIZE => 2, BC=>'n' },  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 12, SIZE => 1, BC=>'C' },  
  ],
);

#####################################################################
#---------------------- STFIOPFILE TYPE ----------------------------#
#####################################################################

%STFIOPFILE_HASH =(
#---- GENERAL DATA RECORD ------------------------------------------ 
  GDR=>[
    {NAME => 'GENERAL_RECORD_SIZE',        POS =>  0, SIZE => 4, },
    {NAME => 'NEXT_FILE_RECORD_NO',        POS =>  4, SIZE => 4, },  
    {NAME => 'EXCH_ID',                    POS =>  8, SIZE => 24,},  
    {NAME => 'MEASURING_PROG',             POS => 32, SIZE => 4, },  
    {NAME => 'REPORT_ID',                  POS => 36, SIZE => 4, },  
    {NAME => 'COLLECTION_INTERVAL_MINS',   POS => 40, SIZE => 4, },  
    {NAME => 'RESULTS_PRINTOUT_NO',        POS => 44, SIZE => 6, },  
    {NAME => 'START_DATE',                 POS => 50, SIZE => 6, },  
    {NAME => 'START_TIME',                 POS => 56, SIZE => 4, },  
    {NAME => 'END_TIME',                   POS => 60, SIZE => 4, },  
    {NAME => 'COLLECTION_FAILURE_INFO',    POS => 64, SIZE => 6, },  
    {NAME => 'NO_RECORDS',                 POS => 70, SIZE => 4, },  
    {NAME => 'REPORT_FAULT_CODE',          POS => 74, SIZE => 4, },  
  ],

#---- OBJECT TYPE RECORD ------------------------------------------- 
  OTR=>[
    {NAME => 'OBJ_TYPE_ID',                POS =>  0, SIZE => 10,},
    {NAME => 'OBJ_GROUP_NO',               POS => 10, SIZE => 4, },  
    {NAME => 'OBJ_TYPE_FAULT_CODE',        POS => 14, SIZE => 4, },  
    {NAME => 'NO_OBJ_RECORDS',             POS => 18, SIZE => 6, },  
    {NAME => 'NO_COUNTERS',                POS => 24, SIZE => 2, },  
    {NAME => 'COUNTER_NAME',               POS => 26, SIZE => 16,},  
  ],

#---- OBJECT RECORD ------------------------------------------------ 
  OR=>[
    {NAME => 'OBJ_ID',                     POS =>  0, SIZE => 16,},
    {NAME => 'COUNTER_VALUE',              POS => 16, SIZE => 10,},  
  ],
);

#####################################################################
#---------------------- MTRRCRFILE TYPE ----------------------------#
#####################################################################

%MTRRCRFILE_HASH =(
#---- ADMIN RECORD ------------------------------------------------- 
  0 =>[
    {NAME => 'FUNCTION_CODE',             POS =>  0, SIZE => 2, },  
    {NAME => 'EXCH_DESIGNATION',          POS =>  2, SIZE => 12,},  
    {NAME => 'DATA_REC_NO',               POS => 14, SIZE => 5, },  
    {NAME => 'RECORD_INFO',               POS => 19, SIZE => 1, },  
    {NAME => 'NO_RECORDS',                POS => 20, SIZE => 2, },  
    {NAME => 'START_DATE',                POS => 22, SIZE => 6, },  
    {NAME => 'START_TIME',                POS => 28, SIZE => 4, },  
    {NAME => 'RR_CALL_REL_REASON',        POS => 32, SIZE => 16,},  
    {NAME => 'FILLER',                    POS => 48, SIZE => 23,},  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 71, SIZE => 1, },  
  ],

#---- SUBRECORD RECORD 1, Radio Related Call Release --------------- 
  1 =>[
    {NAME => 'REASON',                    POS =>  0, SIZE => 2, },  
    {NAME => 'DATE_CALL_REL',             POS =>  2, SIZE => 6, },  
    {NAME => 'TIME_CALL_REL',             POS =>  8, SIZE => 6, },
    {NAME => 'MOBILE_STN_NO',             POS => 14, SIZE => 12,},
    {NAME => 'MOBILE_STN_SERIAL_NO',      POS => 26, SIZE => 8, },
    {NAME => 'POWER_CLASS',               POS => 34, SIZE => 1, },
    {NAME => 'TRANS_TYPE',                POS => 35, SIZE => 1, },
    {NAME => 'CH_RANGE',                  POS => 36, SIZE => 1, },
    {NAME => 'PROTOC_CBY_IND',            POS => 37, SIZE => 1, },
    {NAME => 'CONTROL_CH',                POS => 38, SIZE => 5, },
    {NAME => 'VOICE_CH_1',                POS => 43, SIZE => 5, },
    {NAME => 'TS_INDICATOR_1',            POS => 48, SIZE => 1, },
    {NAME => 'VOICE_CH_2',                POS => 49, SIZE => 5, },
    {NAME => 'TS_INDICATOR_2',            POS => 54, SIZE => 1, },
    {NAME => 'EXCHANGE_1',                POS => 55, SIZE => 7, },
    {NAME => 'EXCHANGE_2',                POS => 62, SIZE => 7, },
    {NAME => 'FILLER',                    POS => 69, SIZE => 2, },  
    {NAME => 'INDICATOR_FOR_END_R',       POS => 71, SIZE => 1, },  
  ],

);

#####################################################################
#---------------------- SEQS FILE TYPE -----------------------------#
#####################################################################

%SEQSFILE_HASH =(
#---- ADM RECORD ---------------------------------------------------
  1=>[
    {NAME => 'RECORD_TYPE',                POS =>  0, SIZE => 1, },
    {NAME => 'EXCH_ID',                    POS =>  1, SIZE => 12,},
    {NAME => 'START_DATE',                 POS => 13, SIZE => 6, },
    {NAME => 'START_TIME',                 POS => 19, SIZE => 4, },
    {NAME => 'MEASURING_PROG',             POS => 23, SIZE => 3, },
    {NAME => 'NO_RES_OPERIOD',             POS => 26, SIZE => 3, },
    {NAME => 'RESULT_OPERIOD_MINS',        POS => 29, SIZE => 4, },
    {NAME => 'RES_OPERIOD_NO',             POS => 33, SIZE => 3, },
    {NAME => 'GLOBAL_RES_OPERIOD_NO',      POS => 36, SIZE => 5, },
    {NAME => 'RECORDING_RESULT',           POS => 41, SIZE => 1, },
    {NAME => 'MEASURING_PROG_STATE',       POS => 42, SIZE => 1, },
    {NAME => 'NO_RECORDS',                 POS => 43, SIZE => 1, },
    {NAME => 'TYPE_OF_OUTPUT',             POS => 44, SIZE => 1, },
    {NAME => 'REG_QUOTA',                  POS => 45, SIZE => 5, },
    {NAME => 'REACHED_QUOTA_DATE',         POS => 50, SIZE => 6, },
    {NAME => 'REACHED_QUOTA_TIME',         POS => 56, SIZE => 4, },
    {NAME => 'NO_CALLS_REG_POS',           POS => 60, SIZE => 10,},
    {NAME => 'SELECTION_CRITERIA',         POS => 70, SIZE => 1, },
    {NAME => 'CRITERIA_ID',                POS => 71, SIZE => 7, },
    {NAME => 'TYPE_OF_REC_OBJ',            POS => 78, SIZE => 1, },
    {NAME => 'NO_REC_OBJ',                 POS => 79, SIZE => 1, },
    {NAME => 'LAST_BLK_INDICATOR',         POS => 80, SIZE => 1, },
    {NAME => 'DATA_BLK_NO',                POS => 81, SIZE => 1, },
    {NAME => 'FAULT_CODE',                 POS => 82, SIZE => 2, },
    {NAME => 'FILLER',                     POS => 84, SIZE => 6, },
  ],

#---- REGEVENT RECORD ----------------------------------------------
  2=>[
    {NAME => 'RECORD_TYPE',                POS =>  0, SIZE =>  1,},
    {NAME => 'RECORD_ID',                  POS =>  1, SIZE =>  7,},
    {NAME => 'NDISCREGIN',                 POS =>  8, SIZE => 10,},
    {NAME => 'NDISCREGOUT',                POS => 18, SIZE => 10,},
    {NAME => 'NTHCON',                     POS => 28, SIZE => 10,},
    {NAME => 'NANSWERS',                   POS => 38, SIZE => 10,},
    {NAME => 'NREPBEFD',                   POS => 48, SIZE => 10,},
    {NAME => 'NREPDURD',                   POS => 58, SIZE => 10,},
    {NAME => 'NREPAFTD',                   POS => 68, SIZE => 10,},
    {NAME => 'NREPWITH',                   POS => 78, SIZE => 10,},
    {NAME => 'NREPEXCE',                   POS => 88, SIZE => 10,},
    {NAME => 'NTOBEFDIAL',                 POS => 98, SIZE => 10,},
    {NAME => 'NTODURDIAL',                 POS =>108, SIZE => 10,},
    {NAME => 'NTOBEFANS',                  POS =>118, SIZE => 10,},
    {NAME => 'NSUBBUSY',                   POS =>128, SIZE => 10,},
    {NAME => 'NNOUTSRVC',                  POS =>138, SIZE => 10,},
    {NAME => 'NNNOTEXIST',                 POS =>148, SIZE => 10,},
    {NAME => 'NBUSYNANSCW',                POS =>158, SIZE => 10,},
    {NAME => 'NTOOUTTK',                   POS =>168, SIZE =>  5,},
    {NAME => 'NTOCSDR',                    POS =>173, SIZE =>  5,},
    {NAME => 'NFLTSIGITR',                 POS =>178, SIZE =>  5,},
    {NAME => 'NFLTSIGCR',                  POS =>183, SIZE =>  5,},
    {NAME => 'NFLTSIGOTR',                 POS =>188, SIZE =>  5,},
    {NAME => 'NFLTSIGCS',                  POS =>193, SIZE =>  5,},
    {NAME => 'NHWFLTINTK',                 POS =>198, SIZE =>  5,},
    {NAME => 'NHWFLTCR',                   POS =>203, SIZE =>  5,},
    {NAME => 'NHWFLTOUTTK',                POS =>208, SIZE =>  5,},
    {NAME => 'NHWFLTCS',                   POS =>213, SIZE =>  5,},
    {NAME => 'NHWFLTTS',                   POS =>218, SIZE =>  5,},
    {NAME => 'NHWFLTJT',                   POS =>223, SIZE =>  5,},
    {NAME => 'NCRELSPCH',                  POS =>228, SIZE =>  5,},
    {NAME => 'NCONGOTR',                   POS =>233, SIZE =>  5,},
    {NAME => 'NCONGTW',                    POS =>238, SIZE =>  5,},
    {NAME => 'NCONGJT',                    POS =>243, SIZE =>  5,},
    {NAME => 'NGRPSWCONG',                 POS =>248, SIZE =>  5,},
    {NAME => 'NCONGNET',                   POS =>253, SIZE =>  5,},
    {NAME => 'NTDBLO',                     POS =>258, SIZE => 10,},
    {NAME => 'NCNCSEVTG',                  POS =>268, SIZE => 10,},
    {NAME => 'NSPARE1',                    POS =>278, SIZE =>  5,},
    {NAME => 'NSPARE2',                    POS =>283, SIZE =>  5,},
    {NAME => 'NSPARE3',                    POS =>288, SIZE =>  5,},
    {NAME => 'NSPARE4',                    POS =>293, SIZE =>  5,},
    {NAME => 'NSPARE5',                    POS =>298, SIZE =>  5,},
    {NAME => 'NSPARE6',                    POS =>303, SIZE =>  5,},
    {NAME => 'NSPARE7',                    POS =>308, SIZE =>  5,},
    {NAME => 'NSPARE8',                    POS =>313, SIZE =>  5,},
    {NAME => 'NSPARE9',                    POS =>318, SIZE =>  5,},
    {NAME => 'NSPARE10',                   POS =>323, SIZE =>  5,},
    {NAME => 'NSPARE11',                   POS =>328, SIZE =>  5,},
    {NAME => 'NSPARE12',                   POS =>333, SIZE =>  5,},
    {NAME => 'NSPARE13',                   POS =>338, SIZE =>  5,},
    {NAME => 'NSPARE14',                   POS =>343, SIZE =>  5,},
    {NAME => 'NSPARE15',                   POS =>348, SIZE =>  5,},
    {NAME => 'NSPARE16',                   POS =>353, SIZE =>  5,},
    {NAME => 'NPDDBELOW1',                 POS =>358, SIZE => 10,},
    {NAME => 'NPDDBELOW2',                 POS =>368, SIZE => 10,},
    {NAME => 'NPDDBELOW23',                POS =>378, SIZE => 10,},
    {NAME => 'NPDDBELOW3',                 POS =>388, SIZE => 10,},
    {NAME => 'NAABOVETL1',                 POS =>398, SIZE => 10,},
    {NAME => 'NAABOVETL2',                 POS =>408, SIZE => 10,},
    {NAME => 'NCTBCTL1',                   POS =>418, SIZE => 10,},
    {NAME => 'NCTBCTL2',                   POS =>428, SIZE => 10,},
    {NAME => 'NCRELHW',                    POS =>438, SIZE =>  5,},
    {NAME => 'NCRELSIG',                   POS =>443, SIZE =>  5,},
    {NAME => 'FILLER',                     POS =>448, SIZE =>  2,},
  ],

#---- ADM RECOVERY RECORD -------------------------------------------
  3=>[
    {NAME => 'RECORDING_TYPE',             POS =>  0, SIZE => 1, },
    {NAME => 'EXCH_ID',                    POS =>  1, SIZE => 12,},
    {NAME => 'START_DATE',                 POS => 13, SIZE => 6, },
    {NAME => 'START_TIME',                 POS => 19, SIZE => 4, },
    {NAME => 'MEASURING_PROG',             POS => 23, SIZE => 3, },
    {NAME => 'TYPE_OF_OUTPUT',             POS => 26, SIZE => 1, },
    {NAME => 'REASON_FOR_LOSS',            POS => 27, SIZE => 7, },
    {NAME => 'FIRST_GLOBAL_ROP_NO',        POS => 34, SIZE => 5, },
    {NAME => 'LAST_GLOBAL_ROP_NO',         POS => 39, SIZE => 5, },
    {NAME => 'DATA_BLK_NO',                POS => 44, SIZE => 1, },
    {NAME => 'FILLER',                     POS => 45, SIZE => 5, },
  ],
);

#####################################################################
#---------------------- TRDIPFILE TYPE -----------------------------#
#####################################################################
%TRDIPFILE_HASH =(
#---- ADM RECORD --------------------------------------------------- 
  ADM=>[
    {NAME => 'RECORDING_TYPE',             POS =>  0, SIZE => 1, },  
    {NAME => 'EXCH_ID',                    POS =>  1, SIZE => 12,},  
    {NAME => 'MEASURING_PROG',             POS => 13, SIZE => 3, },  
    {NAME => 'RESULT_OPERIOD_NO',          POS => 16, SIZE => 3, },  
    {NAME => 'GLOBAL_ROP_NO',              POS => 19, SIZE => 5, },  
    {NAME => 'NO_RESULTS_OPERIOD',         POS => 24, SIZE => 3, },  
    {NAME => 'LENGTH_RESULTS',             POS => 27, SIZE => 4, },  
    {NAME => 'START_DATE',                 POS => 31, SIZE => 6, },  
    {NAME => 'START_TIME',                 POS => 37, SIZE => 4, },  
    {NAME => 'NETWORK_MGMT_RESULT',        POS => 41, SIZE => 1, },  
    {NAME => 'SELECTION_TYPE',             POS => 42, SIZE => 1, },  
    {NAME => 'NO_RECORDS',                 POS => 43, SIZE => 2, },  
    {NAME => 'NO_SCANNINGS',               POS => 45, SIZE => 4, },  
    {NAME => 'INTERVAL_BTWN_SCANNINGS',    POS => 49, SIZE => 3, },  
    {NAME => 'RECORDING_RESULT',           POS => 52, SIZE => 1, },  
    {NAME => 'INDICATION_LAST_BLOCK',      POS => 53, SIZE => 1, },  
    {NAME => 'DATA_BLOCK_NO',              POS => 54, SIZE => 3, },  
    {NAME => 'FILLER',                     POS => 57, SIZE => 7, },  
  ],

#---- OBJECT RECORD ------------------------------------------------ 
  OBJECT=>[
    {NAME => 'SELECTION_ID',               POS =>  0, SIZE => 7, },  
    {NAME => 'RECORDING_ID',               POS =>  7, SIZE => 7, },  
    {NAME => 'NO_CONNECTED_CALLS',         POS => 14, SIZE => 5, },  
    {NAME => 'NO_REJECTED_CALLS',          POS => 19, SIZE => 5, },  
    {NAME => 'NO_SIEZURE_ATTMPS',          POS => 24, SIZE => 5, },  
    {NAME => 'NO_FAILED_SIEZURE_ATTMPS',   POS => 29, SIZE => 5, },  
    {NAME => 'NO_BANSWERS',                POS => 34, SIZE => 5, },  
    {NAME => 'ACC_SIEZURE_TIME_OUTG',      POS => 39, SIZE => 6, },  
    {NAME => 'ACC_TRAFFL_CONNECTION',      POS => 45, SIZE => 6, },  
    {NAME => 'ACC_TRAFFL_BANSWERS',        POS => 51, SIZE => 6, },  
    {NAME => 'FILLER',                     POS => 57, SIZE => 7, },  
  ],

#---- ADMLOST RECORD ----------------------------------------------- 
  ADMLOST=>[
    {NAME => 'RECORDING_TYPE',             POS =>  0, SIZE => 1, },  
    {NAME => 'EXCH_ID',                    POS =>  1, SIZE => 12,},  
    {NAME => 'MEASURING_PROG',             POS => 13, SIZE => 3, },  
    {NAME => 'START_DATE',                 POS => 16, SIZE => 6, },  
    {NAME => 'START_TIME',                 POS => 22, SIZE => 4, },  
    {NAME => 'REASON_FOR_LOSS',            POS => 26, SIZE => 1, },  
    {NAME => 'FIRST_ROP_NO_LOST',          POS => 27, SIZE => 5, },  
    {NAME => 'LAST_ROP_NO_LOST',           POS => 32, SIZE => 5, },  
    {NAME => 'FILLER',                     POS => 37, SIZE => 27,},  
  ],

#---- BLOCKNAMES for given RECORDING TYPE and SELECTION CRITERIA --
  1 =>[
    {SELECTION => 1,    BLOCKNAME => 'INRTDEST'  },
    {SELECTION => 2,    BLOCKNAME => 'OUTRTDEST' },
    {SELECTION => 3,    BLOCKNAME => 'DEST'      },
    {SELECTION => 4,    BLOCKNAME => 'DEST'      },
  ],

  2 =>[
    {SELECTION => 1,    BLOCKNAME => 'TRDIP'      },
    {SELECTION => 2,    BLOCKNAME => 'TRDIP'      },
    {SELECTION => 3,    BLOCKNAME => 'TRDIP'      },
    {SELECTION => 4,    BLOCKNAME => 'RTDESTIN'   },
  ],

  3 =>[
    {SELECTION => 1,    BLOCKNAME => 'TRDIP'     },
    {SELECTION => 2,    BLOCKNAME => 'TRDIP'     },
    {SELECTION => 3,    BLOCKNAME => 'TRDIP'     },
    {SELECTION => 4,    BLOCKNAME => 'RTDESTOUT' },
  ],
);

sub engine_config{
    return \@rules;
}

1;
